About these sample files
========================

``soup.html`` is tag soup based on http://www.w3.org/History/19921103-hypertext/hypertext/WWW/ .

The mojibake and krokozyabry files are not UTF-8, so be sure that your editor doesn't convert them by accident.

``webtv.net_tvfoutreach_cocountdownto666.html`` is a real life sample from https://web.archive.org/web/20130930123935/http://community-2.webtv.net/TvFoutreach/COUNTDOWNTO666 . chardet says it's ISO-8859-2 with confidence 0.71 (out of 1.0).

``xkcd_1.html`` is from http://xkcd.com/1/ . ``xkcd_1_evil.html`` is a corrupt version.

``kcna.html``  is from http://kcna.co.jp/ it is UTF-16 LE.

``videogame_top.htm`` is from http://www.geocities.jp/gamehouse_grindcrusher2/videogame_top.htm which is a variant of shift_jis (shift_jis_2004 and shift_jisx0213 are able to decode it).

``rss.xml`` is from http://en.wikipedia.org/wiki/RSS

``twitchplayspokemonfirered.html`` is from https://docs.google.com/document/d/1Vr1qicRf2WR24F0-zk4ozvPsM3CM1PScjQ0ySR_nAB0/preview downloaded on 2014-04-20T00:12:53Z.
